@@ -27,7 +27,7 @@
 #include <ctype.h>
 #include <sys/types.h>
 
-#if defined(HAVE_SYS_SHM_H)
+#if HAVE_SYS_SHM_H
 #include <sys/ipc.h>
 #include <sys/shm.h>
 #endif
@@ -258,7 +258,7 @@ void
 on_callentry_changed (GtkEditable * editable, gpointer user_data)
 {
 	gchar *call; 
-#if defined(HAVE_SYS_SHM_H)
+#if HAVE_SYS_SHM_H
 	gchar *errorstr;
 #endif
 
@@ -268,7 +268,7 @@ on_callentry_changed (GtkEditable * editable, gpointer user_data)
 	updateb4dialog_and_typeaheadfind (call);
 
 	/* twpsk support, if no IPC ID yet, create one */
-#if defined(HAVE_SYS_SHM_H)
+#if HAVE_SYS_SHM_H
 	if (state.shmid == -1)	
 	{
 		if ((state.shmid = shmget (KEY, SHMSIZE, IPC_CREAT | 0600)) < 0)
