@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,9 @@
  */
 
 #include <gtk/gtk.h>
+#include <string.h>
 #include "callbacks_mainwindow_toolbar.h"
+#include "callbacks_mainwindow_menu.h"
 #include "support.h"
 #include "preferences.h"
 #include "types.h"
@@ -36,6 +38,7 @@
 
 extern GtkWidget *mainwindow;
 extern GtkWidget *mainnotebook;
+extern GtkWidget *keyerwindow;
 extern preferencestype preferences;
 extern statetype state;
 extern gchar **bandsplit;
@@ -48,14 +51,16 @@ void
 on_abutton_clicked (GtkButton * button, gpointer user_data)
 {
 	GtkWidget *dateentry, *gmtentry, *callentry, *rstentry, *myrstentry,
-		*remarksentry, *bandentry, *modeentry, *bandoptionmenu,
+		*remtv, *bandentry, *modeentry, *bandoptionmenu,
 		*modeoptionmenu, *incheckbutton, *outcheckbutton,
-		*qsoframe, *endhbox, *endentry, *powerhbox,
+		*qsoframe, *endhbox, *endentry, *powerhbox, *count,
 		*powerentry, *namehbox, *nameentry, *qthhbox, *qthentry,
 		*locatorhbox, *locatorentry, *unknown1hbox, *unknownentry1,
 		*unknown2hbox, *unknownentry2, *qslhbox, *remarksvbox, *framelabel;
+	GtkTextBuffer *b;
+	GtkTextIter start, end;
 	gchar *temp;
-	gint bandindex, modeindex, i = 0, page;
+	gint bandindex, modeindex, i = 0, page, c;
 	logtype *logw = NULL;
 	GtkTreeIter iter, selected;
 	GtkTreeModel *model;
@@ -175,9 +180,11 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		remarksvbox = lookup_widget (mainwindow, "remarksvbox");
 		if (GTK_WIDGET_VISIBLE (remarksvbox))
 		{
-			remarksentry = lookup_widget (mainwindow, "remarksentry");
-			qso[REMARKS] = gtk_editable_get_chars (GTK_EDITABLE (remarksentry), 0, -1);
-			gtk_editable_delete_text (GTK_EDITABLE (remarksentry), 0, -1);
+			remtv = lookup_widget (mainwindow, "remtv");
+			b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (remtv));
+			gtk_text_buffer_get_bounds (b, &start, &end);
+			qso[REMARKS] = gtk_text_buffer_get_text (b, &start, &end, TRUE);
+			gtk_text_buffer_set_text (b, "", 0);
 		}
 
 		/* add the QSO */
@@ -226,9 +233,16 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 
 		qsoframe = lookup_widget (mainwindow, "qsoframe");
 		framelabel = gtk_frame_get_label_widget (GTK_FRAME(qsoframe));
-		gtk_label_set_text (GTK_LABEL (framelabel), _("New QSO"));
+		temp = g_strdup_printf ("<b>%s</b>", _("New QSO"));
+		gtk_label_set_markup (GTK_LABEL (framelabel), temp);
 
 		gtk_widget_grab_focus (callentry);
+		if (keyerwindow)
+		{	/* increment counter for next QSO */
+			count = lookup_widget (keyerwindow, "count");
+			c = gtk_spin_button_get_value (GTK_SPIN_BUTTON (count));
+			gtk_spin_button_set_value (GTK_SPIN_BUTTON (count), c + 1);
+		}
 	}
 }
 
@@ -238,9 +252,10 @@ void
 on_dbutton_clicked (GtkButton * button, gpointer user_data)
 {
 	GtkWidget *gmtbutton, *gmtentry, *endentry, *callentry, *bandentry,
-		*modeentry, *rstentry, *myrstentry, *remarksentry, *powerentry,
+		*modeentry, *rstentry, *myrstentry, *remtv, *powerentry,
 		*nameentry, *qthentry, *unknownentry1, *unknownentry2,
 		*locatorentry, *incheckbutton, *outcheckbutton;
+	GtkTextBuffer *b;
 	gchar *statustext, *qsonumber;
 	gint i, page;
 	logtype *logw;
@@ -266,7 +281,7 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 			modeentry = lookup_widget (mainwindow, "modeentry");
 			rstentry = lookup_widget (mainwindow, "rstentry");
 			myrstentry = lookup_widget (mainwindow, "myrstentry");
-			remarksentry = lookup_widget (mainwindow, "remarksentry");
+			remtv = lookup_widget (mainwindow, "remtv");
 			incheckbutton = lookup_widget (mainwindow, "incheckbutton");
 			outcheckbutton = lookup_widget (mainwindow, "outcheckbutton");
 			powerentry = lookup_widget (mainwindow, "powerentry");
@@ -282,7 +297,8 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 			gtk_editable_delete_text (GTK_EDITABLE (bandentry), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (rstentry), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (myrstentry), 0, -1);
-			gtk_editable_delete_text (GTK_EDITABLE (remarksentry), 0, -1);
+			b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (remtv));
+			gtk_text_buffer_set_text (b, "", 0);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (outcheckbutton), FALSE);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (incheckbutton), FALSE);
 			gtk_editable_delete_text (GTK_EDITABLE (powerentry), 0, -1);
@@ -334,15 +350,17 @@ void
 on_ubutton_clicked (GtkButton * button, gpointer user_data)
 {
 	GtkWidget *dateentry, *gmtentry, *callentry, *rstentry, *myrstentry,
-		*remarksentry, *bandentry, *modeentry, *incheckbutton,
+		*remtv, *bandentry, *modeentry, *incheckbutton,
 		*outcheckbutton, *modeoptionmenu, *bandoptionmenu,
 		*qsoframe, *endhbox, *endentry, *powerhbox,
 		*powerentry, *namehbox, *nameentry, *qthhbox, *qthentry,
 		*locatorhbox, *locatorentry, *unknown1hbox, *unknownentry1,
 		*unknown2hbox, *unknownentry2, *qslhbox, *remarksvbox, *gmtbutton,
 		*framelabel;
+	GtkTextBuffer *b;
+	GtkTextIter start, end;
 	gint bandindex, modeindex, i = 0, page;
-	gchar *statustext;
+	gchar *statustext, *temp;
 	logtype *logw;
 	GtkTreeIter selected;
 	GtkTreeModel *model;
@@ -472,9 +490,11 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			remarksvbox = lookup_widget (mainwindow, "remarksvbox");
 			if (GTK_WIDGET_VISIBLE (remarksvbox))
 			{
-				remarksentry = lookup_widget (mainwindow, "remarksentry");
-				qso[REMARKS] = gtk_editable_get_chars (GTK_EDITABLE (remarksentry), 0, -1);
-				gtk_editable_delete_text (GTK_EDITABLE (remarksentry), 0, -1);
+				remtv = lookup_widget (mainwindow, "remtv");
+				b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (remtv));
+				gtk_text_buffer_get_bounds (b, &start, &end);
+				qso[REMARKS] = gtk_text_buffer_get_text (b, &start, &end, TRUE);
+				gtk_text_buffer_set_text (b, "", 0);
 			}
 
 			/* change the selected QSO */
@@ -498,7 +518,9 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 
 			qsoframe = lookup_widget (mainwindow, "qsoframe");
 			framelabel = gtk_frame_get_label_widget (GTK_FRAME(qsoframe));
-			gtk_label_set_text (GTK_LABEL (framelabel), _("New QSO"));
+			temp = g_strdup_printf ("<b>%s</b>", _("New QSO"));
+			gtk_label_set_markup (GTK_LABEL (framelabel), temp);
+			g_free (temp);
 
 			if (preferences.saving == 2)
 			{
