@@ -33,6 +33,11 @@
 #include "log.h"
 #include "utils.h"
 
+#if WANT_HAMLIB
+#include "hamlib-utils.h"
+#include "hamlib/rig.h"
+#endif
+
 extern GtkWidget *mainwindow;
 extern GtkWidget *keyerwindow;
 extern preferencestype preferences;
@@ -81,57 +86,6 @@ set_autosave (gint value, gint saving)
 	preferences.saving = saving;
 }
 
-/* set the theme if changed */
-void
-set_theme (gchar * color, gchar * font, gboolean alsoforlog)
-{
-	GtkWidget *clocklabel, *qsoframe, *dxccframe, *locatorframe,
-		*splabel, *cqlabel;
-	gint i;
-	logtype *logwindow;
-	gint logcolor;
-#if WANT_HAMLIB
-	GtkWidget *frequencylabel;
-#endif
-
-	logcolor = alsoforlog ? 1 : 0;
-
-	if (g_ascii_strcasecmp (color, preferences.themecolor) ||
-			g_ascii_strcasecmp (font, preferences.themefont))
-	{
-		clocklabel = lookup_widget (mainwindow, "clocklabel");
-		setlabelstyle (clocklabel, color, font);
-#if WANT_HAMLIB
-		frequencylabel = lookup_widget (mainwindow, "frequencylabel");
-		setlabelstyle (frequencylabel, color, font);
-#endif
-		qsoframe = lookup_widget (mainwindow, "qsoframe");
-		dxccframe = lookup_widget (mainwindow, "dxccframe");
-		locatorframe = lookup_widget (mainwindow, "locatorframe");
-		setframestyle (qsoframe, color, font);
-		setframestyle (dxccframe, color, font);
-		setframestyle (locatorframe, color, font);
-		for (i = 0; i < g_list_length (logwindowlist); i++)
-		{
-			logwindow = g_list_nth_data (logwindowlist, i);
-			setlabelstyle (logwindow->label, color, font);
-		}
-		if (keyerwindow)
-		{
-			cqlabel = lookup_widget (keyerwindow, "cqlabel");
-			splabel = lookup_widget (keyerwindow, "splabel");
-			if (keyerstate.cqmode)
-				setlabelstyle (cqlabel, color, NULL);
-			else
-				setlabelstyle (splabel, color, NULL);
-		}
-		preferences.themecolor = color;
-		preferences.themefont = g_strdup (font);
-	}
-
-	preferences.logcolor = logcolor;
-}
-
 /* set savepath if changed */
 void
 set_path (gchar * pathstr)
@@ -221,7 +175,7 @@ set_clock (gboolean on)
 
 #if WANT_HAMLIB
 /* check if hamlib has changed */
-gboolean hamlib_changed (gint hamlibwidgets, gchar *radio, gchar *device, 
+gboolean hamlib_changed (gint hamlibwidgets, gint rigid, gchar *device, 
 	gint polltime, gchar *rigconf)
 {
 
@@ -229,7 +183,7 @@ gboolean hamlib_changed (gint hamlibwidgets, gchar *radio, gchar *device,
 		return TRUE;
 	else if (g_ascii_strcasecmp (preferences.rigconf, rigconf))
 		return TRUE;
-	else if (g_ascii_strcasecmp (preferences.radio, radio))
+	else if (preferences.rigid != rigid)
 		return TRUE;
 	else if (g_ascii_strcasecmp (preferences.device, device))
 		return TRUE;
@@ -359,3 +313,84 @@ on_hamlibcheckbutton_toggled (GtkToggleButton * togglebutton,
 	}
 }
 
+#if WANT_HAMLIB
+void
+on_radiobutton_clicked (GtkButton * button, gpointer user_data)
+{
+	GtkWidget *rigdialog, *riglistdialogvbox, *riglisttreeview,
+		*rigscrolledwindow, *radioentry;
+	gint i, response, numrigs, rigid;
+	gchar *temp;
+	GtkTreeStore *rigstore;
+	GtkTreeModel *model;
+	GtkTreeIter rigiter, selected;
+	GtkTreeViewColumn *column;
+	GtkCellRenderer *renderer;
+	GtkTreeSelection *sel;
+	GList *riglist;
+	struct rig_caps *rcaps = NULL;
+
+	rigdialog = gtk_dialog_new_with_buttons (_("xlog - select a radio"),
+		GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
+		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
+	gtk_widget_set_size_request (rigdialog, 400, 300);
+	riglistdialogvbox = gtk_vbox_new (FALSE, 0);
+	gtk_container_add
+		(GTK_CONTAINER (GTK_DIALOG(rigdialog)->vbox), riglistdialogvbox);
+	rigscrolledwindow = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW
+		(rigscrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    gtk_box_pack_start (GTK_BOX (riglistdialogvbox),
+		rigscrolledwindow, TRUE, TRUE, 0);
+	gtk_box_reorder_child (GTK_BOX (riglistdialogvbox), rigscrolledwindow, 0);
+	rigstore = gtk_tree_store_new (3, G_TYPE_INT, G_TYPE_STRING, G_TYPE_STRING);
+	riglisttreeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (rigstore));
+	renderer = gtk_cell_renderer_text_new ();
+	column = gtk_tree_view_column_new_with_attributes
+		("Rigid", renderer, "text", 0, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (riglisttreeview), column);
+	renderer = gtk_cell_renderer_text_new ();
+	column = gtk_tree_view_column_new_with_attributes
+		(_("Model"), renderer, "text", 1, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (riglisttreeview), column);
+	renderer = gtk_cell_renderer_text_new ();
+	column = gtk_tree_view_column_new_with_attributes
+		(_("Manufacturer"), renderer, "text", 2, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (riglisttreeview), column);
+
+	gtk_tree_sortable_set_sort_column_id
+		(GTK_TREE_SORTABLE (rigstore), 1, GTK_SORT_ASCENDING);
+	g_object_unref (G_OBJECT (rigstore));
+	gtk_container_add (GTK_CONTAINER (rigscrolledwindow), riglisttreeview);
+
+	riglist = rig_get_list ();
+	numrigs = g_list_length (riglist);
+	for (i = 0; i < numrigs; i++)
+	{
+		rcaps = (struct rig_caps *) g_list_nth_data (riglist, i);
+		gtk_tree_store_append (rigstore, &rigiter, NULL);
+		gtk_tree_store_set (rigstore, &rigiter,
+			0, rcaps->rig_model, 1, rcaps->model_name,  2, rcaps->mfg_name, -1);
+	}
+	gtk_widget_show_all (rigdialog);
+
+	response = gtk_dialog_run (GTK_DIALOG(rigdialog));
+	if (response == GTK_RESPONSE_OK)
+	{
+		sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (riglisttreeview));
+		radioentry = lookup_widget (preferencesdialog, "radioentry");
+		if (gtk_tree_selection_get_selected (sel, &model, &selected))
+		{
+			gtk_tree_model_get (model, &selected, 0, &rigid, -1);
+			temp = g_strdup_printf ("%d", rigid);
+			gtk_entry_set_text (GTK_ENTRY(radioentry), temp);
+			g_free (temp);
+		}
+		else
+			gtk_entry_set_text (GTK_ENTRY(radioentry), "1");
+	}
+	g_list_free (riglist);
+	gtk_widget_destroy (rigdialog);
+}
+#endif
