@@ -143,7 +143,8 @@ printokbutton_clicked (gpointer user_data)
 		myrstok = FALSE, qsloutok = FALSE, qslinok = FALSE, powerok = FALSE, 
 		nameok = FALSE, qthok = FALSE, locatorok = FALSE, u1ok = FALSE,
 		u2ok = FALSE, remarksok = FALSE;
-	gchar *temp, *fontsize, *papersize, *psfile, **item, *pathstr, *test;
+	gchar *temp, *fontsize, *psfile, **item, *pathstr, *papersize;
+    guchar *test;
 	gint i, j, k = 0, printhigh, printlow;
 	gint wnr = 100, wdate = 100, wgmt = 100, wgmtend = 100, wcall = 100, wband = 100,
 		wmode = 100, wrst = 100, wmyrst = 100, wqslout = 100,	wqslin = 100, wpower = 100,
@@ -323,26 +324,35 @@ printokbutton_clicked (gpointer user_data)
 	/* configure printing */
 	job = gnome_print_job_new (NULL);
 	config = gnome_print_job_get_config (job);
-	result = gnome_print_config_set (config, "Printer", "GENERIC");
-	test = gnome_print_config_get (config, "Printer");
+
+	result = gnome_print_config_set
+		(config, (const guchar *)"Printer", (const guchar *)"GENERIC");
+	test = gnome_print_config_get (config, (const guchar *)"Printer");
+
 	if (!test)
 	{
 		update_statusbar (_("Cannot get printer configuration, aborting..."));
 		return;
 	}
-	result = gnome_print_config_set (config, GNOME_PRINT_KEY_PAPER_SIZE, 
-		papersize);
+	result = gnome_print_config_set (config,
+		(const guchar *)GNOME_PRINT_KEY_PAPER_SIZE, (const guchar *)papersize);
+
 	/* page size needed to calculate text position */
 	if (preferences.printdestination == 1)
 		gnome_print_job_print_to_file (job, psfile);
+
 	/* libgnomeprint fallback does not work for me */
-	font = gnome_font_find_closest ("Sans Regular", atoi(fontsize));
+	font = gnome_font_find_closest
+		((const guchar *)"Sans Regular", atoi(fontsize));
 	if (!font)
-		font = gnome_font_find_closest ("Serif Regular", atoi(fontsize));
+		font = gnome_font_find_closest
+			((const guchar *)"Serif Regular", atoi(fontsize));
 	if (!font)
-		font = gnome_font_find_closest ("Helvetica", atoi(fontsize));
+		font = gnome_font_find_closest
+			((const guchar *)"Helvetica", atoi(fontsize));
 	if (!font)
-		font = gnome_font_find_closest ("Times", atoi(fontsize));
+		font = gnome_font_find_closest
+			((const guchar *)"Times", atoi(fontsize));
 
 	/* font width and height needed to calculate text position */
 	gpc = gnome_print_job_get_context (job);
@@ -354,8 +364,10 @@ printokbutton_clicked (gpointer user_data)
 	else
 		fheight = atoi (fontsize);
 
-	bfont = gnome_font_find_closest ("Sans Bold", atoi (fontsize));
-	ifont = gnome_font_find_closest ("Sans Italic", atoi (fontsize));
+	bfont = gnome_font_find_closest
+		((const guchar *)"Sans Bold", atoi (fontsize));
+	ifont = gnome_font_find_closest
+		((const guchar *)"Sans Italic", atoi (fontsize));
 	ws = gnome_font_get_width_utf8 (font, "  ");
 
 	if (preferences.printall == 0)
@@ -387,7 +399,7 @@ printokbutton_clicked (gpointer user_data)
 			if ((k % 30 == 0 && preferences.printorientation == 1) /* landscape */
 				|| (k % 50 == 0 && preferences.printorientation == 0)) /* portrait */
 			{
-				gnome_print_beginpage (gpc, "");
+				gnome_print_beginpage (gpc, (const guchar *)"");
 				gnome_print_setfont (gpc, font);
 				if (preferences.printorientation == 1) /* landscape */
 				{
@@ -403,136 +415,136 @@ printokbutton_clicked (gpointer user_data)
 				if (nrok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "Nr");
+					gnome_print_show (gpc, (const guchar *)"Nr");
 					wnr = colwidth (logwindow, NR, i, preferences.printorientation, font, bfont);
 					left = left + ws + wnr;
 				}
 				if (dateok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "Date");
+					gnome_print_show (gpc, (const guchar *)"Date");
 					wdate = colwidth (logwindow, DATE, i, preferences.printorientation, font, bfont);
 					left = left + ws + wdate;
 				}
 				if (gmtok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "GMT");
+					gnome_print_show (gpc, (const guchar *)"GMT");
 					wgmt = colwidth (logwindow, GMT, i, preferences.printorientation, font, bfont);
 					left = left + ws + wgmt;
 				}
 				if (gmtendok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "END");
+					gnome_print_show (gpc, (const guchar *)"END");
 					wgmtend = colwidth (logwindow, GMTEND, i, preferences.printorientation, font, bfont);
 					left = left + ws + wgmtend;
 				}
 				if (callok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "Callsign");
+					gnome_print_show (gpc, (const guchar *)"Callsign");
 					wcall = colwidth (logwindow, CALL, i, preferences.printorientation, font, bfont);
 					left = left + ws + wcall;
 				}
 				if (bandok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "MHz");
+					gnome_print_show (gpc, (const guchar *)"MHz");
 					wband = colwidth (logwindow, BAND, i, preferences.printorientation, font, bfont);
 					left = left + ws + wband;
 				}
 				if (modeok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "Mode");
+					gnome_print_show (gpc, (const guchar *)"Mode");
 					wmode = colwidth (logwindow, MODE, i, preferences.printorientation, font, bfont);
 					left = left + ws + wmode;
 				}
 				if (rstok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "TX");
+					gnome_print_show (gpc, (const guchar *)"TX");
 					wrst = colwidth (logwindow, RST, i, preferences.printorientation, font, bfont);
 					left = left + ws + wrst;
 				}
 				if (myrstok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "RX");
+					gnome_print_show (gpc, (const guchar *)"RX");
 					wmyrst = colwidth (logwindow, MYRST, i, preferences.printorientation, font, bfont);
 					left = left + ws + wmyrst;
 				}
 				if (qsloutok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "Out");
+					gnome_print_show (gpc, (const guchar *)"Out");
 					wqslout = colwidth (logwindow, QSLOUT, i, preferences.printorientation, font, bfont);
 					left = left + ws + wqslout;
 				}
 				if (qslinok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "In");
+					gnome_print_show (gpc, (const guchar *)"In");
 					wqslin = colwidth (logwindow, QSLIN, i, preferences.printorientation, font, bfont);
 					left = left + ws + wqslin;
 				}
 				if (powerok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "Pwr");
+					gnome_print_show (gpc, (const guchar *)"Pwr");
 					wpower = colwidth (logwindow, POWER, i, preferences.printorientation, font, bfont);
 					left = left + ws + wpower;
 				}
 				if (nameok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "Name");
+					gnome_print_show (gpc, (const guchar *)"Name");
 					wname = colwidth (logwindow, NAME, i, preferences.printorientation, font, bfont);
 					left = left + ws + wname;
 				}
 				if (qthok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "QTH");
+					gnome_print_show (gpc, (const guchar *)"QTH");
 					wqth = colwidth (logwindow, QTH, i, preferences.printorientation, font, bfont);
 					left = left + ws + wqth;
 				}
 				if (locatorok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "Locator");
+					gnome_print_show (gpc, (const guchar *)"Locator");
 					wlocator = colwidth (logwindow, LOCATOR, i, preferences.printorientation, font, bfont);
 					left = left + ws + wlocator;
 				}
 				if (u1ok)
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, preferences.freefield1);
+					gnome_print_show (gpc, (const guchar *)preferences.freefield1);
 					wu1 = colwidth (logwindow, U1, i, preferences.printorientation, font, bfont);
 					left = left + ws + wu1;
 				}
 				if (u2ok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, preferences.freefield2);
+					gnome_print_show (gpc, (const guchar *)preferences.freefield2);
 					wu2 = colwidth (logwindow, U2, i, preferences.printorientation, font, bfont);
 					left = left + ws + wu2;
 				}
 				if (remarksok) 
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "Remarks");
+					gnome_print_show (gpc, (const guchar *)"Remarks");
 					wremarks = colwidth (logwindow, REMARKS, i, preferences.printorientation, font, bfont);
 					left = left + ws + wremarks;
 				}
 				if (contest)
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "Mult");
+					gnome_print_show (gpc, (const guchar *)"Mult");
 					left = left + ws + gnome_font_get_width_utf8 (bfont, "Mult");
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, "Points");
+					gnome_print_show (gpc, (const guchar *)"Points");
 				}
 				top = top - fheight;
 				left = LEFTMARGIN;
@@ -557,25 +569,25 @@ printokbutton_clicked (gpointer user_data)
 			if (nrok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[NR]);
+				gnome_print_show (gpc, (const guchar *)item[NR]);
 				left = left + ws + wnr;
 			}
 			if (dateok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[DATE]);
+				gnome_print_show (gpc, (const guchar *)item[DATE]);
 				left = left + ws + wdate;
 			}
 			if (gmtok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[GMT]);
+				gnome_print_show (gpc, (const guchar *)item[GMT]);
 				left = left + ws + wgmt;
 			}
 			if (gmtendok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[GMTEND]);
+				gnome_print_show (gpc, (const guchar *)item[GMTEND]);
 				left = left + ws + wgmtend;
 			}
 			if (callok) 
@@ -583,7 +595,7 @@ printokbutton_clicked (gpointer user_data)
 				if (bfont) 
 					gnome_print_setfont (gpc, bfont);
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[CALL]);
+				gnome_print_show (gpc, (const guchar *)item[CALL]);
 				left = left + ws + wcall;
 				if (font) 
 					gnome_print_setfont (gpc, font);
@@ -591,79 +603,79 @@ printokbutton_clicked (gpointer user_data)
 			if (bandok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[BAND]);
+				gnome_print_show (gpc, (const guchar *)item[BAND]);
 				left = left + ws + wband;
 			}
 			if (modeok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[MODE]);
+				gnome_print_show (gpc, (const guchar *)item[MODE]);
 				left = left + ws + wmode;
 			}
 			if (rstok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[RST]);
+				gnome_print_show (gpc, (const guchar *)item[RST]);
 				left = left + ws + wrst;
 			}
 			if (myrstok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[MYRST]);
+				gnome_print_show (gpc, (const guchar *)item[MYRST]);
 				left = left + ws + wmyrst;
 			}
 			if (qsloutok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[QSLOUT]);
+				gnome_print_show (gpc, (const guchar *)item[QSLOUT]);
 				left = left + ws + wqslout;
 			}
 			if (qslinok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[QSLIN]);
+				gnome_print_show (gpc, (const guchar *)item[QSLIN]);
 				left = left + ws + wqslin;
 			}
 			if (powerok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[POWER]);
+				gnome_print_show (gpc, (const guchar *)item[POWER]);
 				left = left + ws + wpower;
 			}
 			if (nameok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[NAME]);
+				gnome_print_show (gpc, (const guchar *)item[NAME]);
 				left = left + ws + wname;
 			}
 			if (qthok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[QTH]);
+				gnome_print_show (gpc, (const guchar *)item[QTH]);
 				left = left + ws + wqth;
 			}
 			if (locatorok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[LOCATOR]);
+				gnome_print_show (gpc, (const guchar *)item[LOCATOR]);
 				left = left + ws + wlocator;
 			}
 			if (u1ok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[U1]);
+				gnome_print_show (gpc, (const guchar *)item[U1]);
 				left = left + ws + wu1;
 			}
 			if (u2ok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[U2]);
+				gnome_print_show (gpc, (const guchar *)item[U2]);
 				left = left + ws + wu2;
 			}
 			if (remarksok) 
 			{
 				gnome_print_moveto (gpc, left, top);
-				gnome_print_show (gpc, item[REMARKS]);
+				gnome_print_show (gpc, (const guchar *)item[REMARKS]);
 				left = left + ws + wremarks;
 			}
 			if (contest)
@@ -688,7 +700,7 @@ printokbutton_clicked (gpointer user_data)
 				top = top - 2 * fheight;
 				temp = g_strdup_printf ("Printed by %s version %s", PACKAGE, VERSION);
 				gnome_print_moveto (gpc, left + pwidth/2 - 100, top);
-				gnome_print_show (gpc, temp);
+				gnome_print_show (gpc, (const guchar *)temp);
 				/* end page and start a new one */
 				gnome_print_showpage (gpc);
 			}
@@ -711,7 +723,7 @@ printokbutton_clicked (gpointer user_data)
 		top = top - 2 * fheight;
 		temp = g_strdup_printf ("Printed by %s version %s", PACKAGE, VERSION);
 		gnome_print_moveto (gpc, left + pwidth/2 - 100, top);
-		gnome_print_show (gpc, temp);
+		gnome_print_show (gpc, (const guchar *)temp);
 		gnome_print_showpage (gpc);
 		}
 	}
