@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,5 @@
  * callbacks_printdialog.h
  */
 
-void on_printokbutton_clicked (GtkButton * button, gpointer user_data);
-void on_printcancelbutton_clicked (GtkButton * button, gpointer user_data);
-gboolean on_printdialog_delete_event (GtkWidget * widget, GdkEvent * event, gpointer user_data);
+void printokbutton_clicked (gpointer user_data);
 void on_printradiobutton_toggled (GtkToggleButton * togglebutton, gpointer user_data);
