@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,16 +44,19 @@ cleanup_dxcc (void)
 	gint i;
 
 	/* free the dxcc array */
-	for (i = 0; i < dxcc->len; i++)
+	if (dxcc)
 	{
-		dxcc_data *d = g_ptr_array_index (dxcc, i);
-		g_free (d->countryname);
-		g_free (d->continent);
-		g_free (d->px);
-		g_free (d->exceptions);
-		g_free (d);
+		for (i = 0; i < dxcc->len; i++)
+		{
+			dxcc_data *d = g_ptr_array_index (dxcc, i);
+			g_free (d->countryname);
+			g_free (d->continent);
+			g_free (d->px);
+			g_free (d->exceptions);
+			g_free (d);
+		}
+		g_ptr_array_free (dxcc, TRUE);
 	}
-	g_ptr_array_free (dxcc, TRUE);
 	if (prefixes) g_hash_table_destroy (prefixes);
 }
 
@@ -345,7 +348,7 @@ updatedxccframe (gchar * callsign)
 		*dxcclabel5, *dxccframe, *framelabel;
 	gchar *labeltext1, *labeltext2, *labeltext3, *labeltext4, *gcresult;
 	gint country = -1, iexc;
-	gchar **excsplit, *exc;
+	gchar **excsplit, *exc, *temp;
 	gboolean exception = FALSE;
 
 	dxcclabel1 = lookup_widget (mainwindow, "dxcclabel1");
@@ -361,19 +364,21 @@ updatedxccframe (gchar * callsign)
 	gcresult = g_strdup ("");
 	
 	framelabel = gtk_frame_get_label_widget (GTK_FRAME(dxccframe));
-	gtk_label_set_text (GTK_LABEL (framelabel), "DXCC");
+	gtk_label_set_markup (GTK_LABEL (framelabel), "<b>DXCC</b>");
 
 	if (g_ascii_strcasecmp (callsign, "") != 0)
 	{
 		country = lookup_dxcc (callsign);
 		framelabel = gtk_frame_get_label_widget (GTK_FRAME(dxccframe));
-		gtk_label_set_text (GTK_LABEL (framelabel), callsign);
+		temp = g_strdup_printf ("<b>%s</b>", callsign);
+		gtk_label_set_markup (GTK_LABEL (framelabel), temp);
+		g_free (temp);
 	}
 
 	if (country > 0)
 	{
 		dxcc_data *d = g_ptr_array_index (dxcc, country);
-		labeltext1 = g_strdup (d->countryname);
+		labeltext1 = g_strdup_printf ("<b><i>%s</i></b>", d->countryname);
 		/* look for exceptions */ 
 		if (strchr(d->exceptions, '(') || strchr(d->exceptions, '['))
 		{
@@ -394,22 +399,24 @@ updatedxccframe (gchar * callsign)
 		if (! exception)
 			labeltext2 = g_strdup_printf ("%s - ITU %d - CQ %d", d->continent, d->itu, d->waz);
 		labeltext3 = g_strdup_printf (_("Timezone: %+1.1f"), (gdouble)d->timezone/10);
-		labeltext4 = g_strdup_printf (_("Location: %+1.2f %+1.2f"),	(gdouble)d->latitude/100, (gdouble)d->longitude/100);
-		gcresult = g_strdup (gc(preferences.units, state.mylocation, (gdouble)d->latitude/100, (gdouble)d->longitude/100));
+		labeltext4 = g_strdup_printf (_("Location: %+1.2f %+1.2f"),
+			(gdouble)d->latitude/100, (gdouble)d->longitude/100);
+		gcresult = g_strdup_printf ("<small>%s</small>",
+			gc(preferences.units, state.mylocation, (gdouble)d->latitude/100, (gdouble)d->longitude/100));
 	}
 	else
 	{
 		labeltext1 = g_strdup ("");
 		labeltext2 = g_strdup ("");
 	}
-	gtk_label_set_text (GTK_LABEL (dxcclabel1), labeltext1);
+	gtk_label_set_markup (GTK_LABEL (dxcclabel1), labeltext1);
 	gtk_label_set_text (GTK_LABEL (dxcclabel2), labeltext2);
 	g_free (labeltext1);
 	g_free (labeltext2);
 
 	gtk_label_set_text (GTK_LABEL (dxcclabel3), labeltext3);
 	gtk_label_set_text (GTK_LABEL (dxcclabel4), labeltext4);
-	gtk_label_set_text (GTK_LABEL (dxcclabel5), gcresult);
+	gtk_label_set_markup (GTK_LABEL (dxcclabel5), gcresult);
 	g_free (labeltext3);
 	g_free (labeltext4);
 	g_free (gcresult);
