@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,11 +28,13 @@
 
 #include <gtk/gtk.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include "types.h"
 #include "gui_b4dialog.h"
 #include "support.h"
 #include "log.h"
+#include "utils.h"
 
 extern preferencestype preferences;
 extern GList *logwindowlist;
@@ -125,6 +127,67 @@ on_b4dialog_delete_event (GtkWidget * widget, GdkEvent * event,
 	return TRUE;		/* do not destroy */
 }
 
+/* colorize the callsign, green if match, red if same band/frequency */
+/* TODO: make this work with frequency/mode retrieved with hamlib
+static void
+colorize (GtkTreeViewColumn *col, GtkCellRenderer *renderer,
+	GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+{
+	gchar *call, *band, *realband, *mode, *b4call, *b4mode, *b4band,
+		*realb4band;
+	GtkWidget *callentry, *modeentry, *bandentry, *bandoptionmenu,
+		*modeoptionmenu;
+	gint bandindex, modeindex;
+	GdkColor b4bg;
+
+	gtk_tree_model_get(model, iter, CALL + 1, &b4call, -1);
+	callentry = lookup_widget (mainwindow, "callentry");
+	call = gtk_editable_get_chars (GTK_EDITABLE (callentry), 0, -1);
+	if (strlen(call) == strlen(b4call))
+	{
+		gtk_tree_model_get(model, iter, BAND + 1, &b4band, -1);
+		gtk_tree_model_get(model, iter, MODE + 1, &b4mode, -1);
+		modeentry = lookup_widget (mainwindow, "modeentry");
+		bandentry = lookup_widget (mainwindow, "bandentry");
+		bandoptionmenu = lookup_widget (mainwindow, "bandoptionmenu");
+		modeoptionmenu = lookup_widget (mainwindow, "modeoptionmenu");
+		if (preferences.modeseditbox == 0)
+		{
+			modeindex = gtk_combo_box_get_active
+				(GTK_COMBO_BOX(modeoptionmenu));
+			mode = lookup_mode (modeindex);
+		}
+		else
+			mode = gtk_editable_get_chars (GTK_EDITABLE (modeentry), 0, -1);
+		if (preferences.bandseditbox == 0)
+		{
+			bandindex = gtk_combo_box_get_active
+				(GTK_COMBO_BOX(bandoptionmenu));
+			band = lookup_band (bandindex);
+			realband = g_strdup (band);
+		}
+		else
+		{
+			band = gtk_editable_get_chars (GTK_EDITABLE (bandentry), 0, -1);
+			realband = finddot (band);
+		}
+		realb4band = finddot (b4band);
+		if (!g_ascii_strcasecmp (mode, b4mode) &&
+				!g_ascii_strcasecmp (realband, realb4band))
+			gdk_color_parse ("red", &b4bg);
+		else
+			gdk_color_parse ("green", &b4bg);
+		g_object_set (renderer, "background-gdk", &b4bg, NULL);
+
+		g_free (realband);
+		g_free (band);
+		g_free (mode);
+	}
+	else
+		g_object_set (renderer, "background-gdk", NULL, NULL);
+}
+*/
+
 GtkWidget*
 create_b4dialog (void)
 {
@@ -139,7 +202,7 @@ create_b4dialog (void)
 
 	b4dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title (GTK_WINDOW (b4dialog), _("xlog - worked before"));
-	b4dialog_icon_pixbuf = create_pixbuf ("xlog.png");
+	b4dialog_icon_pixbuf = create_pixbuf ("xlog-b4.png");
 	if (b4dialog_icon_pixbuf)
 		{
 			gtk_window_set_icon (GTK_WINDOW (b4dialog), b4dialog_icon_pixbuf);
@@ -147,7 +210,6 @@ create_b4dialog (void)
 		}
 
 	b4dialogvbox = gtk_vbox_new (FALSE, 0);
-	gtk_widget_show (b4dialogvbox);
 	gtk_container_add (GTK_CONTAINER (b4dialog), b4dialogvbox);
 
 	g_signal_connect ((gpointer) b4dialog, "delete_event",
@@ -157,7 +219,6 @@ create_b4dialog (void)
 	b4scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(b4scrolledwindow),
 		GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_widget_show (b4scrolledwindow);
 	gtk_box_pack_start (GTK_BOX (b4dialogvbox), b4scrolledwindow, TRUE, TRUE, 0);
 	gtk_box_reorder_child (GTK_BOX (b4dialogvbox), b4scrolledwindow, 0);
 	model = gtk_tree_store_new (QSO_FIELDS + 1,
@@ -169,7 +230,6 @@ create_b4dialog (void)
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE(model), 
 		CALL + 1, GTK_SORT_ASCENDING);
 	g_object_unref (G_OBJECT (model));
-	gtk_widget_show (b4treeview);
 	gtk_container_add (GTK_CONTAINER (b4scrolledwindow), b4treeview);
 
 	/* add callback for selecting a row */
@@ -193,16 +253,19 @@ create_b4dialog (void)
 	for (j = 1; j < QSO_FIELDS; j++)
 	{		
 		renderer = gtk_cell_renderer_text_new ();
-			if (j == U1)
-				column = gtk_tree_view_column_new_with_attributes (preferences.freefield1, renderer, "text", j + 1, NULL);
-			else if (j == U2)
-				column = gtk_tree_view_column_new_with_attributes (preferences.freefield2, renderer, "text", j + 1, NULL);
-			else
-				column = gtk_tree_view_column_new_with_attributes (strfield(j), renderer, "text", j + 1, NULL);
-			gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(column), GTK_TREE_VIEW_COLUMN_GROW_ONLY);
-		if (j == CALL) 
-		gtk_tree_view_column_set_sort_column_id (column, CALL + 1);
-			gtk_tree_view_append_column (GTK_TREE_VIEW (b4treeview), column);
+		if (j == U1)
+			column = gtk_tree_view_column_new_with_attributes (preferences.freefield1, renderer, "text", j + 1, NULL);
+		else if (j == U2)
+			column = gtk_tree_view_column_new_with_attributes (preferences.freefield2, renderer, "text", j + 1, NULL);
+		else
+			column = gtk_tree_view_column_new_with_attributes (strfield(j), renderer, "text", j + 1, NULL);
+		gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(column), GTK_TREE_VIEW_COLUMN_GROW_ONLY);
+		if (j == CALL)
+		{
+			gtk_tree_view_column_set_sort_column_id (column, CALL + 1);
+//			gtk_tree_view_column_set_cell_data_func(column, renderer, colorize, NULL, NULL);
+		}
+		gtk_tree_view_append_column (GTK_TREE_VIEW (b4treeview), column);
 	}
 	g_object_set_data_full (G_OBJECT (b4dialog), "b4treeview", 
 		gtk_widget_ref (b4treeview), (GDestroyNotify) gtk_widget_unref);
@@ -214,6 +277,7 @@ create_b4dialog (void)
 		gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), atoi(b4split[i]) ? TRUE : FALSE);
 	}
 	g_strfreev(b4split);
+	gtk_widget_show_all (b4dialogvbox);
 
 	return b4dialog;
 }
