@@ -45,7 +45,7 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		*b410, *b411, *b412, *b413, *b414, *b415, *b416, *b417, *b418,
 		*badif, *hsep, *bu1, *bu2, *bu3, *bu4, *bu5, *bu6, *bu7, *bu8,
 		*bu9, *bu10, *bu11, *bu12, *bu13, *bu14, *bu15, *bu16, *bu17,
-		*b4treeview, *tsvhbox;
+		*b4treeview, *tsvhbox, *bucalc;
 	gchar **states, **split;
 	gboolean check;
 	GtkTreeViewColumn *column;
@@ -142,14 +142,14 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (notebook), vbox);
 
-	label = gtk_label_new (_("Export options for the 'Save As' dialog"));
+	label = gtk_label_new (_("Options for the export dialog"));
 	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 10);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 
 	frame = gtk_frame_new ("ADIF");
 	gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
 	badif = gtk_check_button_new_with_label
-		(_("When saving as ADIF convert frequency to band"));
+		(_("When exporting to ADIF convert frequency to band"));
 	if (preferences.saveasadif == 1)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (badif), TRUE);
 	gtk_container_add (GTK_CONTAINER (frame), badif);
@@ -160,7 +160,7 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 	vbox2 = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (frame), vbox2);
 	label = gtk_label_new
-("Fields to export when saving as TSV (Tab Separated Value) for glabels");
+(_("Fields to export when saving as TSV (Tab Separated Value) for glabels"));
 	gtk_container_add (GTK_CONTAINER (vbox2), label);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	hsep = gtk_hseparator_new ();
@@ -231,10 +231,19 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 
 	g_strfreev(split);
 
+	hsep = gtk_hseparator_new ();
+	gtk_container_add (GTK_CONTAINER (vbox2), hsep);
+	bucalc = gtk_check_button_new_with_label
+(_("Add calculated bearing and distance fields when the locator log field is used"));
+	gtk_label_set_line_wrap	(GTK_LABEL (GTK_BIN (bucalc)->child), TRUE);
+	gtk_toggle_button_set_active
+		(GTK_TOGGLE_BUTTON (bucalc), preferences.tsvcalc);
+	gtk_box_pack_start (GTK_BOX (vbox2), bucalc, FALSE, FALSE, 0);
+
 	label = gtk_label_new (_("Worked Before"));
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook),
 		gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 0), label);
-	label = gtk_label_new (_("Save As"));
+	label = gtk_label_new (_("Export"));
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook),
 		gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 1), label);
 
@@ -438,6 +447,12 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		for (i = 0; i < 17; i++)
 			g_free (states[i]);
 		g_free (states);
+
+		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bucalc));
+		if (check)
+			preferences.tsvcalc = 1;
+		else
+			preferences.tsvcalc = 0;
 	}
 	gtk_widget_destroy (dialogsdialog);
 }
