@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,18 +42,17 @@
 #include "hamlib-utils.h"
 
 typedef struct
-	{
-		time_t modified; /* Last Modified Time */				
-		gchar *filename; /* File Name */
-		FILE *fd;				/* File Descriptor */
-		unsigned long filesize; /* File Size */
-	} fileinfo;
+{
+	time_t modified;		/* Last Modified Time */				
+	gchar *filename;		/* File Name */
+	FILE *fd;				/* File Descriptor */
+	unsigned long filesize; /* File Size */
+} fileinfo;
 
 gint saved_fd;
 gint tracetimer = -1;
 fileinfo finfo;
 
-extern GList *riglist;
 extern gchar *xlogdir;
 extern preferencestype preferences;
 extern GtkWidget *mainwindow;
@@ -73,24 +72,18 @@ stop_tracing (void)
 	stderr = fdopen (STDERR_FILENO, "w");
 #endif
 #endif
-	hamlibresult = start_hamlib (preferences.radio, preferences.device, RIG_DEBUG_NONE, preferences.polltime);
+	hamlibresult = start_hamlib (preferences.rigid, preferences.device,
+		RIG_DEBUG_NONE, preferences.polltime);
 }
 
 static gboolean
 on_tracedialog_delete_event (GtkWidget * widget, GdkEvent * event,
-					 gpointer user_data)
+	 gpointer user_data)
 {
 	stop_tracing ();
 	return FALSE;
 }
 
-static void
-on_tracedialogclosebutton_clicked (GtkButton * button, gpointer user_data)
-{
-	stop_tracing ();
-	gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (button)));
-}
-
 /* check if tracefile has changed */
 static int fileupdated(void) 
 {
@@ -129,7 +122,8 @@ updatetrace (gpointer data)
 							numread = fread(buf, 1, 1024, fd);
 							gtk_text_buffer_insert (buffer, &end, buf, numread);
 							mark = gtk_text_buffer_get_mark (buffer, "insert");
-							gtk_text_view_scroll_to_mark(GTK_TEXT_VIEW(data), mark, 0.0, FALSE, 0.0, 1.0);
+							gtk_text_view_scroll_to_mark(GTK_TEXT_VIEW(data),
+								mark, 0.0, FALSE, 0.0, 1.0);
 						}
 					fclose (fd);
 				}
@@ -140,87 +134,67 @@ updatetrace (gpointer data)
 void
 on_trace_hamlib_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
-	GtkWidget *tracedialog, *tracelabel, *tracedialog_vbox, *tracedialog_mainvbox,
-		*tracedialog_hseparator, *tracedialog_scrolledwindow, *tracedialog_textview,
-		*tracedialog_action_area, *tracedialogclosebutton;
-	GdkPixbuf *tracedialog_icon_pixbuf;
-	gint hamlibresult;
+	GtkWidget *tracedialog, *tracelabel, *vbox,	*tracedialog_hseparator,
+		*tracedialog_scrolledwindow, *tracedialog_textview, *close_button;
+	gint hamlibresult, response;
 	gchar *tracestr;
 	
 	if (preferences.hamlib == 0)
 	{
 		warningdialog ("xlog - trace hamlib", 
-			_("Please enable hamlib from the Preferences -> Settings dialog"));
+			_("Please enable hamlib from the Preferences -> Settings dialog"),
+			"gtk-dialog-warning");
 	}
 	else
 	{
 	/* redirect stderr to a file and start the file monitor,
 		 stop and start hamlib with tracing enabled */
-		tracedialog = gtk_dialog_new ();
-		gtk_widget_set_size_request (tracedialog, 400, 300);
-		gtk_window_set_title (GTK_WINDOW (tracedialog), _("xlog - trace hamlib"));
-		gtk_window_set_position (GTK_WINDOW (tracedialog), GTK_WIN_POS_MOUSE);
-		gtk_window_set_destroy_with_parent (GTK_WINDOW (tracedialog), TRUE);
-		tracedialog_icon_pixbuf = create_pixbuf ("xlog.png");
-		if (tracedialog_icon_pixbuf)
-		{
-			gtk_window_set_icon (GTK_WINDOW (tracedialog), tracedialog_icon_pixbuf);
-			g_object_unref (tracedialog_icon_pixbuf);
-		}
-
-		tracedialog_vbox = GTK_DIALOG (tracedialog)->vbox;
-		gtk_widget_show (tracedialog_vbox);
-	
-		tracedialog_mainvbox = gtk_vbox_new (FALSE, 0);
-		gtk_widget_show (tracedialog_mainvbox);
-		gtk_box_pack_start (GTK_BOX (tracedialog_vbox), tracedialog_mainvbox, TRUE, TRUE, 0);
-
-		tracelabel = gtk_label_new ("");
-		gtk_widget_show (tracelabel);
-		gtk_box_pack_start (GTK_BOX (tracedialog_mainvbox), tracelabel, FALSE, FALSE, 5);
-		gtk_label_set_line_wrap (GTK_LABEL (tracelabel), TRUE);
-
-		tracedialog_hseparator = gtk_hseparator_new ();
-		gtk_widget_show (tracedialog_hseparator);
-		gtk_box_pack_start (GTK_BOX (tracedialog_mainvbox), tracedialog_hseparator, FALSE, FALSE, 0);
-
+		tracedialog = gtk_dialog_new_with_buttons (_("xlog - trace hamlib"),
+			GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT, NULL);
+		close_button = gtk_dialog_add_button (GTK_DIALOG (tracedialog),
+			GTK_STOCK_CLOSE, GTK_RESPONSE_OK);
+		gtk_widget_grab_focus (close_button);
+        gtk_widget_set_size_request (tracedialog, 400, 300);
+		vbox = gtk_vbox_new (FALSE, 0);
+		gtk_container_add (GTK_CONTAINER
+			(GTK_DIALOG (tracedialog)->vbox), vbox);
 		tracedialog_scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
-		gtk_widget_show (tracedialog_scrolledwindow);
-		gtk_box_pack_start (GTK_BOX (tracedialog_mainvbox), tracedialog_scrolledwindow, TRUE, TRUE, 0);
-		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (tracedialog_scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-
+		gtk_box_pack_start
+			(GTK_BOX (vbox), tracedialog_scrolledwindow, TRUE, TRUE, 0);
+		gtk_scrolled_window_set_policy
+			(GTK_SCROLLED_WINDOW (tracedialog_scrolledwindow),
+			GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 		tracedialog_textview = gtk_text_view_new ();
-		gtk_widget_show (tracedialog_textview);
-		gtk_container_add (GTK_CONTAINER (tracedialog_scrolledwindow), tracedialog_textview);
-
-		tracedialog_action_area = GTK_DIALOG (tracedialog)->action_area;
-		gtk_widget_show (tracedialog_action_area);
-		gtk_button_box_set_layout (GTK_BUTTON_BOX (tracedialog_action_area), GTK_BUTTONBOX_SPREAD);
-
-		tracedialogclosebutton = gtk_button_new_from_stock ("gtk-close");
-		gtk_widget_show (tracedialogclosebutton);
-		gtk_dialog_add_action_widget (GTK_DIALOG (tracedialog), tracedialogclosebutton, GTK_RESPONSE_CLOSE);
-		GTK_WIDGET_SET_FLAGS (tracedialogclosebutton, GTK_CAN_DEFAULT);
-
-		g_signal_connect ((gpointer) tracedialog, "delete_event",
-										G_CALLBACK (on_tracedialog_delete_event),
-										NULL);
-		g_signal_connect ((gpointer) tracedialogclosebutton, "clicked",
-										G_CALLBACK (on_tracedialogclosebutton_clicked),
-										NULL);
+		gtk_text_view_set_editable (GTK_TEXT_VIEW(tracedialog_textview), FALSE);
+		gtk_text_view_set_cursor_visible
+			(GTK_TEXT_VIEW(tracedialog_textview), FALSE);
+		gtk_container_add
+			(GTK_CONTAINER (tracedialog_scrolledwindow), tracedialog_textview);
+		tracedialog_hseparator = gtk_hseparator_new ();
+		gtk_box_pack_start
+			(GTK_BOX (vbox), tracedialog_hseparator, FALSE, FALSE, 0);
 
 		saved_fd = dup (STDERR_FILENO);
 		finfo.filename = g_strdup_printf ( "%s/hamlib.out", xlogdir);
+		tracestr = g_strdup_printf (_("Saving to %s"), finfo.filename);
+		tracelabel = gtk_label_new (tracestr);
+		gtk_box_pack_start
+			(GTK_BOX (vbox), tracelabel, FALSE, FALSE, 0);
+		g_free (tracestr);
 		stop_hamlib();
 		finfo.fd = freopen (finfo.filename, "w", stderr);
-		hamlibresult = start_hamlib (preferences.radio, preferences.device, 
+		hamlibresult = start_hamlib (preferences.rigid, preferences.device, 
 			RIG_DEBUG_TRACE, preferences.polltime);
-		tracetimer = g_timeout_add (1000, (GSourceFunc) updatetrace, tracedialog_textview);
+		tracetimer = g_timeout_add
+			(1000, (GSourceFunc) updatetrace, tracedialog_textview);
 
-		tracestr = g_strdup_printf (_("Saving to %s"), finfo.filename);
-		gtk_label_set_text (GTK_LABEL (tracelabel), tracestr);
-		g_free(tracestr);
-		gtk_widget_show (tracedialog);
+		g_signal_connect ((gpointer) tracedialog, "delete_event",
+			G_CALLBACK (on_tracedialog_delete_event), NULL);
+		
+		gtk_widget_show_all (tracedialog);
+		response = gtk_dialog_run (GTK_DIALOG(tracedialog));
+		stop_tracing ();
+		gtk_widget_destroy (tracedialog);
 	}
 }
 #endif
