@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,69 +24,11 @@
 #include <gtk/gtk.h>
 #include "types.h"
 #include "log.h"
+#include "support.h"
 
-extern GdkColormap *colormap;
 extern GtkUIManager *ui_manager;
 extern GList *logwindowlist;
-
-/* set style of a label */
-void
-setlabelstyle (GtkWidget * label, gchar * color, gchar * font)
-{
-	GdkColor themecolor;
-	PangoFontDescription *fnt;
-
-	gdk_color_parse (color, &themecolor);
-	if (!gdk_colormap_alloc_color (colormap, &themecolor, FALSE, TRUE))
-		g_warning ("Allocation of color failed in setlabelstyle");
-
-	gtk_widget_modify_fg (label, GTK_STATE_NORMAL, &themecolor);
-	fnt = pango_font_description_from_string(font);
-	gtk_widget_modify_font(GTK_WIDGET(label), fnt);
-	pango_font_description_free(fnt);
-}
-
-/* set style of a frame */
-void
-setframestyle (GtkWidget * frame, gchar * color, gchar * font)
-{
-	GdkColor themecolor;
-	GtkWidget *label;
-	PangoFontDescription *fnt;
-	GtkStyle *framestyle;
-
-	gdk_color_parse (color, &themecolor);
-	if (!gdk_colormap_alloc_color (colormap, &themecolor, FALSE, TRUE))
-		g_warning ("Allocation of color failed in setframestyle");
-
-	framestyle = gtk_style_copy (frame->style);		
-	framestyle->bg[GTK_STATE_NORMAL] = themecolor;
-	gtk_widget_set_style (GTK_WIDGET (frame), framestyle);
-
-	label = gtk_frame_get_label_widget (GTK_FRAME(frame));
-	gtk_widget_modify_fg (label, GTK_STATE_NORMAL, &themecolor);
-	fnt = pango_font_description_from_string(font);
-	gtk_widget_modify_font(GTK_WIDGET(label), fnt);
-	pango_font_description_free(fnt);
-}
-
-/* get color style of a label */
-gchar *
-getlabelcolor (GtkWidget * label)
-{
-	GtkStyle *labelstyle;
-	GdkColor labelcolor;
-	gchar *col;
-
-	labelstyle = gtk_style_copy (label->style);
-	labelcolor = labelstyle->fg[GTK_STATE_NORMAL];
-
-	col = g_strdup_printf("#%02X%02X%02X",	 
-	labelcolor.red >> 8, labelcolor.green >> 8, labelcolor.blue >> 8);
-
-	return (col);
-}
-
+extern preferencestype preferences;
 
 /* configure "Tabs" menu */
 void set_tabs_menu (void)
@@ -124,3 +66,39 @@ void set_tabs_menu (void)
 		}
 	}
 }
+
+void unselect_logs (void)
+{
+	gint i;
+	logtype *logw;
+	GtkTreeIter selected;
+	GtkTreeModel *model;
+	GtkTreeSelection *sel;
+
+	for (i = 0; i < g_list_length (logwindowlist); i++)
+	{
+		logw = g_list_nth_data (logwindowlist, i);
+		sel = gtk_tree_view_get_selection(GTK_TREE_VIEW (logw->treeview));
+		if (gtk_tree_selection_get_selected	(sel, &model, &selected))
+			gtk_tree_selection_unselect_all (sel);
+	}
+}
+
+/* set the log font */
+void 	 
+set_font (gchar * font) 	 
+{
+	PangoFontDescription *font_description;
+	gint i;
+	logtype *logw;
+
+	font_description = pango_font_description_from_string (font);
+	for (i = 0; i < g_list_length (logwindowlist); i++)
+	{
+		logw = g_list_nth_data (logwindowlist, i);
+		gtk_widget_modify_font (GTK_WIDGET(logw->treeview), font_description);
+	}
+	pango_font_description_free (font_description);
+	preferences.logfont = g_strdup (font);
+}
+
