@@ -21,8 +21,6 @@
  * gui_utils.h
  */
 
-void setlabelstyle (GtkWidget * label, gchar * color, gchar * font);
-void setframestyle (GtkWidget * frame, gchar * color, gchar * font);
-gchar *getlabelcolor (GtkWidget * label);
 void set_tabs_menu (void);
 void unselect_logs (void);
+void set_font (gchar * font);
