@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,8 +27,8 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <string.h>
-#define __USE_XOPEN
-#include <time.h>
+#include <sys/types.h>
+#include <sys/wait.h>
 
 #include "callbacks_mainwindow_list.h"
 #include "gui_utils.h"
@@ -47,6 +47,7 @@ void
 backuplog (gchar * filename, gchar * backupfilename)
 {
 	gint ch;
+	gchar *msg;
 	FILE *in, *out;
 
 	in = fopen (filename, "r");
@@ -59,6 +60,13 @@ backuplog (gchar * filename, gchar * backupfilename)
 				putc (ch, out);
 			fclose (out);
 		}
+		else
+		{
+			msg = g_strdup_printf (_("Backup to %s failed: %s"),
+				backupfilename, g_strerror (errno));
+			g_warning (msg);
+			g_free (msg);
+		}
 		fclose (in);
 	}
 }
@@ -234,6 +242,13 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
 		QSLIN, q[QSLIN], POWER, q[POWER], NAME, name, QTH, qth, LOCATOR, q[LOCATOR], 
 		U1, u1, U2, u2,	REMARKS, remarks, -1);
 
+	if (!(logw->qsos % 1000))
+	{
+		while (gtk_events_pending ())
+			gtk_main_iteration ();
+		update_statusbar (_("Reading..."));
+	}
+
 	for (i = 0; i < QSO_FIELDS; i++)
 		g_free (q[i]);
 
@@ -267,21 +282,6 @@ new_logwindow (void)
 	return (newlog);
 }
 
-static void
-colorize (GtkTreeViewColumn * tree_column, GtkCellRenderer * cell,
-		GtkTreeModel * model, GtkTreeIter * iter, gpointer data)
-{
-	GdkColor bg, fg;
-	PangoFontDescription *font;
-
-	gdk_color_parse (preferences.themecolor, &bg);
-	gdk_color_parse ("white", &fg);
-	font = pango_font_description_from_string (preferences.themefont);
-
-	g_object_set (cell, "background-gdk", &bg, "foreground-gdk", &fg, "font_desc", font, NULL);
-
-	pango_font_description_free (font);
-}
 
 /* open a log and return a struct */
 logtype *
@@ -289,8 +289,8 @@ openlog (LOGDB * lp, gchar * name, gint page)
 {
 	logtype *logwindow;
 	gint i, j;
-	gchar *logn, **w;
-	GtkCellRenderer *renderer;
+	gchar *logn, **w, *labelname;
+	GtkCellRenderer *renderer, *brenderer;
 	GtkTreeViewColumn *column;
 	GObject *selection;
 	GtkTreeStore *model;
@@ -323,12 +323,16 @@ openlog (LOGDB * lp, gchar * name, gint page)
 
 	/* NR column is the first one */
 	renderer = gtk_cell_renderer_text_new ();
-	g_object_set (G_OBJECT (renderer), "xalign", 0.0, NULL);
+	brenderer = gtk_cell_renderer_text_new ();
+	g_object_set (G_OBJECT (brenderer), "weight", "bold", NULL);
 	column = gtk_tree_view_column_new_with_attributes ("NR", renderer, "text", NR, NULL);
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN (column), TRUE);
-	gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN(column), atoi(w[NR]));
 	gtk_tree_view_append_column (GTK_TREE_VIEW (logwindow->treeview), column);
+	if (atoi(w[NR]) == 0)
+		gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
+	else
+		gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN(column), atoi(w[NR]));
 
 	/* see which fields are in the log and add a column or hide it */
 	for (j = 1; j < QSO_FIELDS; j++)
@@ -345,15 +349,13 @@ openlog (LOGDB * lp, gchar * name, gint page)
 		else if (j == U2)
 			column = gtk_tree_view_column_new_with_attributes
 				(preferences.freefield2, renderer, "text", j, NULL);
+		else if (j == CALL)
+			column = gtk_tree_view_column_new_with_attributes 
+				(strfield (j), brenderer, "text", j, NULL);
 		else
 			column = gtk_tree_view_column_new_with_attributes 
 				(strfield (j), renderer, "text", j, NULL);
 
-		/* colorize the callsign column */
-		if (preferences.logcolor == 1 && j == CALL)
-			gtk_tree_view_column_set_cell_data_func 
-				(column, renderer, colorize, NULL, NULL);
-
 		gtk_tree_view_column_set_sizing 
 			(GTK_TREE_VIEW_COLUMN(column), GTK_TREE_VIEW_COLUMN_FIXED);
 		gtk_tree_view_column_set_resizable 
@@ -373,23 +375,35 @@ openlog (LOGDB * lp, gchar * name, gint page)
 
 	/* change the page label */
 	logn = logname (name);
-	logwindow->label = gtk_label_new (logn);
+	logwindow->label = gtk_label_new (NULL);
+	labelname = g_strdup_printf ("<b>%s</b>", logn);
+	gtk_label_set_markup (GTK_LABEL (logwindow->label), labelname);
 	gtk_widget_show (logwindow->label);
+	g_free (labelname);
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (mainnotebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK(mainnotebook), page), logwindow->label);
 	gtk_misc_set_padding (GTK_MISC (logwindow->label), 10, 0);
-	setlabelstyle (logwindow->label, preferences.themecolor, preferences.themefont);
 	logwindow->logname = g_strdup (logn);
 	g_free (logn);
 
 	return (logwindow);
 }
 
+/* close child process when finished */
+static gboolean
+childcheck (void)
+{
+  gint status, childpid;
+
+  childpid = waitpid (-1, &status, WNOHANG);
+  return (WIFEXITED(status) == 0);
+}
+
 /* saving of the log */
 void
 savelog (gpointer arg, gchar * logfile, gint type, gint first, gint last)
 {
 	LOGDB *lp;
-	gint i, j;
+	gint i, j, pid;
 	G_CONST_RETURN gchar *label;
 	gchar **item, *pathstr;
 	gint fields[QSO_FIELDS], widths[QSO_FIELDS];
@@ -416,32 +430,37 @@ savelog (gpointer arg, gchar * logfile, gint type, gint first, gint last)
 		widths[i] = parse_field_width (fields[i]);
 	}
 
-	lp = log_file_create (logfile, type, logw->columns, fields, widths);
-
-	if (lp)
+	pid = fork (); /* use fork for log saving */
+	if (pid == 0)
 	{
-		model = gtk_tree_view_get_model (GTK_TREE_VIEW(logw->treeview));
-		for (i = logw->qsos - first; i >= logw->qsos - last; i--)
+		lp = log_file_create (logfile, type, logw->columns, fields, widths);
+		if (lp)
 		{
-			pathstr = g_strdup_printf ("%d", i);
-			path = gtk_tree_path_new_from_string (pathstr);
-			gtk_tree_model_get_iter (model, &iter, path);
-			for (j = 0; j < logw->columns; j++)
+			model = gtk_tree_view_get_model (GTK_TREE_VIEW(logw->treeview));
+			for (i = logw->qsos - first; i >= logw->qsos - last; i--)
 			{
-				gtk_tree_model_get (model, &iter, logw->logfields[j], &item[fields[j]], -1);
-				if (fields[j] == DATE || fields[j] == NAME || fields[j] == QTH ||	fields[j] == U1 || fields[j] == U2 || fields[j] == REMARKS)
-					item[fields[j]] = g_locale_from_utf8 (item[fields[j]], -1, NULL, NULL, NULL);
+				pathstr = g_strdup_printf ("%d", i);
+				path = gtk_tree_path_new_from_string (pathstr);
+				gtk_tree_model_get_iter (model, &iter, path);
+				for (j = 0; j < logw->columns; j++)
+				{
+					gtk_tree_model_get
+						(model, &iter, logw->logfields[j], &item[fields[j]], -1);
+					if (fields[j] == DATE || fields[j] == NAME || 
+fields[j] == QTH || fields[j] == U1 || fields[j] == U2 || fields[j] == REMARKS)
+						item[fields[j]] = g_locale_from_utf8
+							(item[fields[j]], -1, NULL, NULL, NULL);
+				}
+				log_file_qso_append (lp, item);
+				gtk_tree_path_free (path);
+				g_free (pathstr);
 			}
-			log_file_qso_append (lp, item);
-			gtk_tree_path_free (path);
-			g_free (pathstr);
+			log_file_close (lp);
+			_exit (0);
 		}
-		log_file_close (lp);
-	}
-	else
-	{
-		update_statusbar (_("Creation of logfile failed"));
 	}
+	/* check the child every second */
+	g_timeout_add (1000, (GSourceFunc) childcheck, NULL);
 	g_free (item);
 }
 
