@@ -71,7 +71,7 @@ const struct log_ops adif_ops = {
 static gint adif_qso_foreach
 (LOGDB *handle,  gint (*fn)(LOGDB*, qso_t*, gpointer arg), gpointer arg)
 {
-	gchar line [1024], sdate[16], *buffer, *p;
+	gchar line [1024], sdate[16], *buffer, *p, *tmp;
 	gchar **adifline, **adifitem, **adifid;
 	gint ret, items, i=0;
 	struct tm timestruct;
@@ -87,7 +87,7 @@ static gint adif_qso_foreach
 		if (!fgets (line, 1023, fp)) break;
 
 		if (line[0] != '\n') /* ignore empty lines */
-			buffer = g_strconcat (buffer, line, 0);
+			buffer = g_strconcat (buffer, line, NULL);
 
 		if (g_strrstr (line, "<EOH>") || g_strrstr (line, "<eoh>")) /* read past header */
 			buffer = g_strdup ("");
@@ -144,8 +144,35 @@ static gint adif_qso_foreach
 						if (!q[BAND]) 
 						{
 							adif_field = BAND;
-							q[adif_field] =
-								g_strndup (adifitem[1], atoi(adifid[1]));
+							if (g_strrstr(adifitem[1], "m") ||
+								g_strrstr(adifitem[1], "M"))
+							{ /* convert band to freq */
+					if (g_ascii_strncasecmp (adifitem[1], "160", 3) == 0)
+						q[adif_field] = g_strdup ("1.8");
+					else if (g_ascii_strncasecmp (adifitem[1], "80", 2) == 0)
+						q[adif_field] = g_strdup ("3.5");
+					else if (g_ascii_strncasecmp (adifitem[1], "60", 2) == 0)
+						q[adif_field] = g_strdup ("5.3");
+					else if (g_ascii_strncasecmp (adifitem[1], "40", 2) == 0)
+						q[adif_field] = g_strdup ("7");
+					else if (g_ascii_strncasecmp (adifitem[1], "20", 2) == 0)
+						q[adif_field] = g_strdup ("14");
+					else if (g_ascii_strncasecmp (adifitem[1], "15", 2) == 0)
+						q[adif_field] = g_strdup ("21");
+					else if (g_ascii_strncasecmp (adifitem[1], "10", 2) == 0)
+						q[adif_field] = g_strdup ("28");
+					else if (g_ascii_strncasecmp (adifitem[1], "30", 2) == 0)
+						q[adif_field] = g_strdup ("10");
+					else if (g_ascii_strncasecmp (adifitem[1], "17", 2) == 0)
+						q[adif_field] = g_strdup ("18");
+					else if (g_ascii_strncasecmp (adifitem[1], "12", 2) == 0)
+						q[adif_field] = g_strdup ("24");
+					else
+						q[adif_field] =	g_strndup (adifitem[1], atoi(adifid[1]));
+							}
+							else
+								q[adif_field] =
+									g_strndup (adifitem[1], atoi(adifid[1]));
 						}
 					}
 					else if (!strcasecmp (adifid[0], "FREQ"))
@@ -219,10 +246,34 @@ static gint adif_qso_foreach
 					else if (!strcasecmp (adifid[0], "COMMENT"))
 					{
 						adif_field = REMARKS;
-						q[adif_field] =
-							g_strndup (adifitem[1], atoi(adifid[1]));
+						/* append comment to remarks */
+						if (q[REMARKS])
+						{
+							tmp = g_strndup (adifitem[1], atoi(adifid[1]));
+							q[adif_field] =
+								g_strconcat (q[adif_field], ", ", tmp, NULL);
+							g_free (tmp);
+						}
+						else
+							q[adif_field] =
+								g_strndup (adifitem[1], atoi(adifid[1]));
 					}
-	
+					else if (!strcasecmp (adifid[0], "NOTES"))
+					{
+						adif_field = REMARKS;
+						/* append notes to remarks */
+						if (q[REMARKS])
+						{
+							tmp = g_strndup (adifitem[1], atoi(adifid[1]));
+							q[adif_field] =
+								g_strconcat (q[adif_field], ", ", tmp, NULL);
+							g_free (tmp);
+						}
+						else
+							q[adif_field] =
+								g_strndup (adifitem[1], atoi(adifid[1]));
+
+					}	
 					g_strfreev (adifid);
 					g_strfreev (adifitem);
 				}
