@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@
 
 #include "logfile.h"
 #include "types.h"
+#include "wwl.h"
 
 extern preferencestype preferences;
 
@@ -138,19 +139,15 @@ edi_close (LOGDB * handle)
 	fclose (fp);
 }
 
-extern gdouble wwl_dist(gchar *my, gchar *dx);
 
-/* 
- */
 gint
 edi_qso_append (LOGDB * handle, const qso_t * q)
 {
 	FILE *fp = (FILE *) handle->priv;
 	gchar rst[16], exch[16] = "", my_rst[16], my_exch[16] = "";
-	gchar date[16];
-	gchar *p;
+	gchar *date, *p;
 	gint rst_len;
-	gint mode, kms;
+	gint mode, kms, result, l;
 
 	/*
 	 * there's no exchange fields in xlog. However, the exchange information
@@ -170,8 +167,10 @@ edi_qso_append (LOGDB * handle, const qso_t * q)
 
 	/* AAMMDD */
 	if (strlen (q[DATE]) == 11 && q[DATE][2] == ' ' && q[DATE][6] == ' ')
-		sprintf (date, "%s%02d%c%c", q[DATE] + 9,
+		date = g_strdup_printf ("%s%02d%c%c", q[DATE] + 9,
 			scan_month (q[DATE] + 3), q[DATE][0], q[DATE][1]);
+	else
+		date = g_strdup ("");
 
 	if (!strcmp(q[MODE], "SSB")) {
 		mode = 1;
@@ -192,7 +191,7 @@ edi_qso_append (LOGDB * handle, const qso_t * q)
 	}
 
 	if (q[LOCATOR]) 
-		kms = wwl_dist (preferences.locator, q[LOCATOR]);
+		result = wwl (preferences.locator, q[LOCATOR], &kms, &l);
 	else 
 		kms = 0;
 
@@ -210,6 +209,7 @@ edi_qso_append (LOGDB * handle, const qso_t * q)
 		fprintf (fp, "%s;%s;%s;%d;%s;%s;%s;%s;;;%d;;;;\n",
 		date, q[GMT], q[CALL], mode, rst, exch, my_rst, my_exch, kms);
 
+	g_free (date);
 	return 0;
 }
 
