@@ -32,12 +32,12 @@
 #include <gtk/gtk.h>
 #include <string.h>
 
-#if defined(HAVE_SYS_IPC_H)
+#if HAVE_SYS_IPC_H
 #include <sys/ipc.h>
 #include <sys/msg.h>
 #endif
 
-#if defined(WANT_HAMLIB)
+#if WANT_HAMLIB
 #include <hamlib/rig.h>
 #include "hamlib-utils.h"
 #endif
@@ -377,7 +377,7 @@ main (int argc, char *argv[])
 	}
 
 	/* set up the message queue for remote data */
-#if defined(HAVE_SYS_IPC_H)
+#if HAVE_SYS_IPC_H
 	msgid = msgget ((key_t) 1238, 0666 | IPC_CREAT);
 	if (msgid == -1)
 		{
