@@ -54,7 +54,7 @@
 #include <gtk/gtk.h>
 #include <string.h>
 
-#if defined(HAVE_SYS_IPC_H)
+#if HAVE_SYS_IPC_H
 #include <sys/ipc.h>
 #include <sys/msg.h>
 #endif
@@ -538,7 +538,7 @@ gint
 remote_entry (void)
 {
 	ssize_t status = -1;
-#if defined(HAVE_SYS_IPC_H)
+#if HAVE_SYS_IPC_H
 	glong msgtyp = 0;
 
 	status = msgrcv (msgid, (void *) &msgbuf, 1024, msgtyp,
