@@ -30,12 +30,12 @@
 #include <string.h>
 #include <gtk/gtk.h>
 
-#if defined(HAVE_SYS_IPC_H)
+#if HAVE_SYS_IPC_H
 #include <sys/ipc.h>
 #include <sys/msg.h>
 #endif
 
-#if defined(HAVE_SYS_SHM_H)
+#if HAVE_SYS_SHM_H
 #include <sys/ipc.h>
 #include <sys/shm.h>
 #endif
@@ -323,13 +323,13 @@ save_windowsize_and_cleanup (void)
 		g_source_remove (clocktimer);
 
 	/* remove message queue */
-#if defined(HAVE_SYS_IPC_H)
+#if HAVE_SYS_IPC_H
 	if (msgid != -1)
 		msgctl (msgid, IPC_RMID, 0);
 #endif
 
 	/* detach shared mem and destroy it */
-#if defined(HAVE_SYS_SHM_H)
+#if HAVE_SYS_SHM_H
 	if (state.shmid != -1)
 		{
 			shmdt (shareCall);
